# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: arc_zonal_shift
using AWS.Compat
using AWS.UUIDs

"""
    cancel_zonal_shift(zonal_shift_id)
    cancel_zonal_shift(zonal_shift_id, params::Dict{String,<:Any})

Cancel a zonal shift in Amazon Route 53 Application Recovery Controller that you've started
for a resource in your AWS account in an AWS Region.

# Arguments
- `zonal_shift_id`: The internally-generated identifier of a zonal shift.

"""
function cancel_zonal_shift(zonalShiftId; aws_config::AbstractAWSConfig=global_aws_config())
    return arc_zonal_shift(
        "DELETE",
        "/zonalshifts/$(zonalShiftId)";
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function cancel_zonal_shift(
    zonalShiftId,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return arc_zonal_shift(
        "DELETE",
        "/zonalshifts/$(zonalShiftId)",
        params;
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    get_managed_resource(resource_identifier)
    get_managed_resource(resource_identifier, params::Dict{String,<:Any})

Get information about a resource that's been registered for zonal shifts with Amazon Route
53 Application Recovery Controller in this AWS Region. Resources that are registered for
zonal shifts are managed resources in Route 53 ARC. At this time, you can only start a
zonal shift for Network Load Balancers and Application Load Balancers with cross-zone load
balancing turned off.

# Arguments
- `resource_identifier`: The identifier for the resource to include in a zonal shift. The
  identifier is the Amazon Resource Name (ARN) for the resource. At this time, you can only
  start a zonal shift for Network Load Balancers and Application Load Balancers with
  cross-zone load balancing turned off.

"""
function get_managed_resource(
    resourceIdentifier; aws_config::AbstractAWSConfig=global_aws_config()
)
    return arc_zonal_shift(
        "GET",
        "/managedresources/$(resourceIdentifier)";
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function get_managed_resource(
    resourceIdentifier,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return arc_zonal_shift(
        "GET",
        "/managedresources/$(resourceIdentifier)",
        params;
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    list_managed_resources()
    list_managed_resources(params::Dict{String,<:Any})

Lists all the resources in your AWS account in this AWS Region that are managed for zonal
shifts in Amazon Route 53 Application Recovery Controller, and information about them. The
information includes their Amazon Resource Names (ARNs), the Availability Zones the
resources are deployed in, and the resource name.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"maxResults"`: The number of objects that you want to return with this call.
- `"nextToken"`: Specifies that you want to receive the next page of results. Valid only if
  you received a NextToken response in the previous request. If you did, it indicates that
  more output is available. Set this parameter to the value provided by the previous call's
  NextToken response to request the next page of results.
"""
function list_managed_resources(; aws_config::AbstractAWSConfig=global_aws_config())
    return arc_zonal_shift(
        "GET", "/managedresources"; aws_config=aws_config, feature_set=SERVICE_FEATURE_SET
    )
end
function list_managed_resources(
    params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()
)
    return arc_zonal_shift(
        "GET",
        "/managedresources",
        params;
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    list_zonal_shifts()
    list_zonal_shifts(params::Dict{String,<:Any})

Lists all the active zonal shifts in Amazon Route 53 Application Recovery Controller in
your AWS account in this AWS Region.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"maxResults"`: The number of objects that you want to return with this call.
- `"nextToken"`: Specifies that you want to receive the next page of results. Valid only if
  you received a NextToken response in the previous request. If you did, it indicates that
  more output is available. Set this parameter to the value provided by the previous call's
  NextToken response to request the next page of results.
- `"status"`: A status for a zonal shift. The Status for a zonal shift can have one of the
  following values:    ACTIVE: The zonal shift is started and active.    EXPIRED: The zonal
  shift has expired (the expiry time was exceeded).    CANCELED: The zonal shift was
  canceled.
"""
function list_zonal_shifts(; aws_config::AbstractAWSConfig=global_aws_config())
    return arc_zonal_shift(
        "GET", "/zonalshifts"; aws_config=aws_config, feature_set=SERVICE_FEATURE_SET
    )
end
function list_zonal_shifts(
    params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()
)
    return arc_zonal_shift(
        "GET",
        "/zonalshifts",
        params;
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    start_zonal_shift(away_from, comment, expires_in, resource_identifier)
    start_zonal_shift(away_from, comment, expires_in, resource_identifier, params::Dict{String,<:Any})

You start a zonal shift to temporarily move load balancer traffic away from an Availability
Zone in a AWS Region, to help your application recover immediately, for example, from a
developer's bad code deployment or from an AWS infrastructure failure in a single
Availability Zone. You can start a zonal shift in Route 53 ARC only for managed resources
in your account in an AWS Region. Resources are automatically registered with Route 53 ARC
by AWS services. At this time, you can only start a zonal shift for Network Load Balancers
and Application Load Balancers with cross-zone load balancing turned off. When you start a
zonal shift, traffic for the resource is no longer routed to the Availability Zone. The
zonal shift is created immediately in Route 53 ARC. However, it can take a short time,
typically up to a few minutes, for existing, in-progress connections in the Availability
Zone to complete. For more information, see Zonal shift in the Amazon Route 53 Application
Recovery Controller Developer Guide.

# Arguments
- `away_from`: The Availability Zone that traffic is moved away from for a resource when
  you start a zonal shift. Until the zonal shift expires or you cancel it, traffic for the
  resource is instead moved to other Availability Zones in the AWS Region.
- `comment`: A comment that you enter about the zonal shift. Only the latest comment is
  retained; no comment history is maintained. A new comment overwrites any existing comment
  string.
- `expires_in`: The length of time that you want a zonal shift to be active, which Route 53
  ARC converts to an expiry time (expiration time). Zonal shifts are temporary. You can set a
  zonal shift to be active initially for up to three days (72 hours). If you want to still
  keep traffic away from an Availability Zone, you can update the zonal shift and set a new
  expiration. You can also cancel a zonal shift, before it expires, for example, if you're
  ready to restore traffic to the Availability Zone. To set a length of time for a zonal
  shift to be active, specify a whole number, and then one of the following, with no space:
  &lt;ul&gt; &lt;li&gt; &lt;p&gt; &lt;b&gt;A lowercase letter m:&lt;/b&gt; To specify that
  the value is in minutes.&lt;/p&gt; &lt;/li&gt; &lt;li&gt; &lt;p&gt; &lt;b&gt;A lowercase
  letter h:&lt;/b&gt; To specify that the value is in hours.&lt;/p&gt; &lt;/li&gt;
  &lt;/ul&gt; &lt;p&gt;For example: &lt;code&gt;20h&lt;/code&gt; means the zonal shift
  expires in 20 hours. &lt;code&gt;120m&lt;/code&gt; means the zonal shift expires in 120
  minutes (2 hours).&lt;/p&gt;
- `resource_identifier`: The identifier for the resource to include in a zonal shift. The
  identifier is the Amazon Resource Name (ARN) for the resource. At this time, you can only
  start a zonal shift for Network Load Balancers and Application Load Balancers with
  cross-zone load balancing turned off.

"""
function start_zonal_shift(
    awayFrom,
    comment,
    expiresIn,
    resourceIdentifier;
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return arc_zonal_shift(
        "POST",
        "/zonalshifts",
        Dict{String,Any}(
            "awayFrom" => awayFrom,
            "comment" => comment,
            "expiresIn" => expiresIn,
            "resourceIdentifier" => resourceIdentifier,
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function start_zonal_shift(
    awayFrom,
    comment,
    expiresIn,
    resourceIdentifier,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return arc_zonal_shift(
        "POST",
        "/zonalshifts",
        Dict{String,Any}(
            mergewith(
                _merge,
                Dict{String,Any}(
                    "awayFrom" => awayFrom,
                    "comment" => comment,
                    "expiresIn" => expiresIn,
                    "resourceIdentifier" => resourceIdentifier,
                ),
                params,
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    update_zonal_shift(zonal_shift_id)
    update_zonal_shift(zonal_shift_id, params::Dict{String,<:Any})

Update an active zonal shift in Amazon Route 53 Application Recovery Controller in your AWS
account. You can update a zonal shift to set a new expiration, or edit or replace the
comment for the zonal shift.

# Arguments
- `zonal_shift_id`: The identifier of a zonal shift.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"comment"`: A comment that you enter about the zonal shift. Only the latest comment is
  retained; no comment history is maintained. A new comment overwrites any existing comment
  string.
- `"expiresIn"`: The length of time that you want a zonal shift to be active, which Route
  53 ARC converts to an expiry time (expiration time). Zonal shifts are temporary. You can
  set a zonal shift to be active initially for up to three days (72 hours). If you want to
  still keep traffic away from an Availability Zone, you can update the zonal shift and set a
  new expiration. You can also cancel a zonal shift, before it expires, for example, if
  you're ready to restore traffic to the Availability Zone. To set a length of time for a
  zonal shift to be active, specify a whole number, and then one of the following, with no
  space:    A lowercase letter m: To specify that the value is in minutes.    A lowercase
  letter h: To specify that the value is in hours.   For example: 20h means the zonal shift
  expires in 20 hours. 120m means the zonal shift expires in 120 minutes (2 hours).
"""
function update_zonal_shift(zonalShiftId; aws_config::AbstractAWSConfig=global_aws_config())
    return arc_zonal_shift(
        "PATCH",
        "/zonalshifts/$(zonalShiftId)";
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function update_zonal_shift(
    zonalShiftId,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return arc_zonal_shift(
        "PATCH",
        "/zonalshifts/$(zonalShiftId)",
        params;
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
