# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: sqs
using AWS.Compat
using AWS.UUIDs

"""
    add_permission(awsaccount_id, action_name, label, queue_url)
    add_permission(awsaccount_id, action_name, label, queue_url, params::Dict{String,<:Any})

Adds a permission to a queue for a specific principal. This allows sharing access to the
queue. When you create a queue, you have full control access rights for the queue. Only
you, the owner of the queue, can grant or deny permissions to the queue. For more
information about these permissions, see Allow Developers to Write Messages to a Shared
Queue in the Amazon SQS Developer Guide.     AddPermission generates a policy for you. You
can use  SetQueueAttributes  to upload your policy. For more information, see Using Custom
Policies with the Amazon SQS Access Policy Language in the Amazon SQS Developer Guide.   An
Amazon SQS policy can have a maximum of seven actions per statement.   To remove the
ability to change queue permissions, you must deny permission to the AddPermission,
RemovePermission, and SetQueueAttributes actions in your IAM policy.   Amazon SQS
AddPermission does not support adding a non-account principal.     Cross-account
permissions don't apply to this action. For more information, see Grant cross-account
permissions to a role and a username in the Amazon SQS Developer Guide.

# Arguments
- `awsaccount_id`: The Amazon Web Services account numbers of the principals who are to
  receive permission. For information about locating the Amazon Web Services account
  identification, see Your Amazon Web Services Identifiers in the Amazon SQS Developer Guide.
- `action_name`: The action the client wants to allow for the specified principal. Valid
  values: the name of any action or *. For more information about these actions, see Overview
  of Managing Access Permissions to Your Amazon Simple Queue Service Resource in the Amazon
  SQS Developer Guide. Specifying SendMessage, DeleteMessage, or ChangeMessageVisibility for
  ActionName.n also grants permissions for the corresponding batch versions of those actions:
  SendMessageBatch, DeleteMessageBatch, and ChangeMessageVisibilityBatch.
- `label`: The unique identification of the permission you're setting (for example,
  AliceSendMessage). Maximum 80 characters. Allowed characters include alphanumeric
  characters, hyphens (-), and underscores (_).
- `queue_url`: The URL of the Amazon SQS queue to which permissions are added. Queue URLs
  and names are case-sensitive.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"AWSAccountIds"`: The Amazon Web Services account numbers of the principals who are to
  receive permission. For information about locating the Amazon Web Services account
  identification, see Your Amazon Web Services Identifiers in the Amazon SQS Developer Guide.
- `"Actions"`: The action the client wants to allow for the specified principal. Valid
  values: the name of any action or *. For more information about these actions, see Overview
  of Managing Access Permissions to Your Amazon Simple Queue Service Resource in the Amazon
  SQS Developer Guide. Specifying SendMessage, DeleteMessage, or ChangeMessageVisibility for
  ActionName.n also grants permissions for the corresponding batch versions of those actions:
  SendMessageBatch, DeleteMessageBatch, and ChangeMessageVisibilityBatch.
"""
function add_permission(
    AWSAccountId,
    ActionName,
    Label,
    QueueUrl;
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "AddPermission",
        Dict{String,Any}(
            "AWSAccountId" => AWSAccountId,
            "ActionName" => ActionName,
            "Label" => Label,
            "QueueUrl" => QueueUrl,
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function add_permission(
    AWSAccountId,
    ActionName,
    Label,
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "AddPermission",
        Dict{String,Any}(
            mergewith(
                _merge,
                Dict{String,Any}(
                    "AWSAccountId" => AWSAccountId,
                    "ActionName" => ActionName,
                    "Label" => Label,
                    "QueueUrl" => QueueUrl,
                ),
                params,
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    cancel_message_move_task(task_handle)
    cancel_message_move_task(task_handle, params::Dict{String,<:Any})

Cancels a specified message movement task.    A message movement can only be cancelled when
the current status is RUNNING.   Cancelling a message movement task does not revert the
messages that have already been moved. It can only stop the messages that have not been
moved yet.

# Arguments
- `task_handle`: An identifier associated with a message movement task.

"""
function cancel_message_move_task(
    TaskHandle; aws_config::AbstractAWSConfig=global_aws_config()
)
    return sqs(
        "CancelMessageMoveTask",
        Dict{String,Any}("TaskHandle" => TaskHandle);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function cancel_message_move_task(
    TaskHandle,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "CancelMessageMoveTask",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("TaskHandle" => TaskHandle), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    change_message_visibility(queue_url, receipt_handle, visibility_timeout)
    change_message_visibility(queue_url, receipt_handle, visibility_timeout, params::Dict{String,<:Any})

Changes the visibility timeout of a specified message in a queue to a new value. The
default visibility timeout for a message is 30 seconds. The minimum is 0 seconds. The
maximum is 12 hours. For more information, see Visibility Timeout in the Amazon SQS
Developer Guide. For example, if the default timeout for a queue is 60 seconds, 15 seconds
have elapsed since you received the message, and you send a ChangeMessageVisibility call
with VisibilityTimeout set to 10 seconds, the 10 seconds begin to count from the time that
you make the ChangeMessageVisibility call. Thus, any attempt to change the visibility
timeout or to delete that message 10 seconds after you initially change the visibility
timeout (a total of 25 seconds) might result in an error. An Amazon SQS message has three
basic states:   Sent to a queue by a producer.   Received from the queue by a consumer.
Deleted from the queue.   A message is considered to be stored after it is sent to a queue
by a producer, but not yet received from the queue by a consumer (that is, between states 1
and 2). There is no limit to the number of stored messages. A message is considered to be
in flight after it is received from a queue by a consumer, but not yet deleted from the
queue (that is, between states 2 and 3). There is a limit to the number of in flight
messages. Limits that apply to in flight messages are unrelated to the unlimited number of
stored messages. For most standard queues (depending on queue traffic and message backlog),
there can be a maximum of approximately 120,000 in flight messages (received from a queue
by a consumer, but not yet deleted from the queue). If you reach this limit, Amazon SQS
returns the OverLimit error message. To avoid reaching the limit, you should delete
messages from the queue after they're processed. You can also increase the number of queues
you use to process your messages. To request a limit increase, file a support request. For
FIFO queues, there can be a maximum of 20,000 in flight messages (received from a queue by
a consumer, but not yet deleted from the queue). If you reach this limit, Amazon SQS
returns no error messages.  If you attempt to set the VisibilityTimeout to a value greater
than the maximum time left, Amazon SQS returns an error. Amazon SQS doesn't automatically
recalculate and increase the timeout to the maximum remaining time. Unlike with a queue,
when you change the visibility timeout for a specific message the timeout value is applied
immediately but isn't saved in memory for that message. If you don't delete a message after
it is received, the visibility timeout for the message reverts to the original timeout
value (not to the value you set using the ChangeMessageVisibility action) the next time the
message is received.

# Arguments
- `queue_url`: The URL of the Amazon SQS queue whose message's visibility is changed. Queue
  URLs and names are case-sensitive.
- `receipt_handle`: The receipt handle associated with the message, whose visibility
  timeout is changed. This parameter is returned by the  ReceiveMessage  action.
- `visibility_timeout`: The new value for the message's visibility timeout (in seconds).
  Values range: 0 to 43200. Maximum: 12 hours.

"""
function change_message_visibility(
    QueueUrl,
    ReceiptHandle,
    VisibilityTimeout;
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "ChangeMessageVisibility",
        Dict{String,Any}(
            "QueueUrl" => QueueUrl,
            "ReceiptHandle" => ReceiptHandle,
            "VisibilityTimeout" => VisibilityTimeout,
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function change_message_visibility(
    QueueUrl,
    ReceiptHandle,
    VisibilityTimeout,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "ChangeMessageVisibility",
        Dict{String,Any}(
            mergewith(
                _merge,
                Dict{String,Any}(
                    "QueueUrl" => QueueUrl,
                    "ReceiptHandle" => ReceiptHandle,
                    "VisibilityTimeout" => VisibilityTimeout,
                ),
                params,
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    change_message_visibility_batch(change_message_visibility_batch_request_entry, queue_url)
    change_message_visibility_batch(change_message_visibility_batch_request_entry, queue_url, params::Dict{String,<:Any})

Changes the visibility timeout of multiple messages. This is a batch version of
ChangeMessageVisibility. The result of the action on each message is reported individually
in the response. You can send up to 10  ChangeMessageVisibility  requests with each
ChangeMessageVisibilityBatch action.  Because the batch request can result in a combination
of successful and unsuccessful actions, you should check for batch errors even when the
call returns an HTTP status code of 200.

# Arguments
- `change_message_visibility_batch_request_entry`: Lists the receipt handles of the
  messages for which the visibility timeout must be changed.
- `queue_url`: The URL of the Amazon SQS queue whose messages' visibility is changed. Queue
  URLs and names are case-sensitive.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Entries"`: Lists the receipt handles of the messages for which the visibility timeout
  must be changed.
"""
function change_message_visibility_batch(
    ChangeMessageVisibilityBatchRequestEntry,
    QueueUrl;
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "ChangeMessageVisibilityBatch",
        Dict{String,Any}(
            "ChangeMessageVisibilityBatchRequestEntry" =>
                ChangeMessageVisibilityBatchRequestEntry,
            "QueueUrl" => QueueUrl,
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function change_message_visibility_batch(
    ChangeMessageVisibilityBatchRequestEntry,
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "ChangeMessageVisibilityBatch",
        Dict{String,Any}(
            mergewith(
                _merge,
                Dict{String,Any}(
                    "ChangeMessageVisibilityBatchRequestEntry" =>
                        ChangeMessageVisibilityBatchRequestEntry,
                    "QueueUrl" => QueueUrl,
                ),
                params,
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    create_queue(queue_name)
    create_queue(queue_name, params::Dict{String,<:Any})

Creates a new standard or FIFO queue. You can pass one or more attributes in the request.
Keep the following in mind:   If you don't specify the FifoQueue attribute, Amazon SQS
creates a standard queue.  You can't change the queue type after you create it and you
can't convert an existing standard queue into a FIFO queue. You must either create a new
FIFO queue for your application or delete your existing standard queue and recreate it as a
FIFO queue. For more information, see Moving From a Standard Queue to a FIFO Queue in the
Amazon SQS Developer Guide.     If you don't provide a value for an attribute, the queue is
created with the default value for the attribute.   If you delete a queue, you must wait at
least 60 seconds before creating a queue with the same name.   To successfully create a new
queue, you must provide a queue name that adheres to the limits related to queues and is
unique within the scope of your queues.  After you create a queue, you must wait at least
one second after the queue is created to be able to use the queue.  To get the queue URL,
use the  GetQueueUrl  action.  GetQueueUrl  requires only the QueueName parameter. be aware
of existing queue names:   If you provide the name of an existing queue along with the
exact names and values of all the queue's attributes, CreateQueue returns the queue URL for
the existing queue.   If the queue name, attribute names, or attribute values don't match
an existing queue, CreateQueue returns an error.    Cross-account permissions don't apply
to this action. For more information, see Grant cross-account permissions to a role and a
username in the Amazon SQS Developer Guide.

# Arguments
- `queue_name`: The name of the new queue. The following limits apply to this name:   A
  queue name can have up to 80 characters.   Valid values: alphanumeric characters, hyphens
  (-), and underscores (_).   A FIFO queue name must end with the .fifo suffix.   Queue URLs
  and names are case-sensitive.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Attribute"`: A map of attributes with their corresponding values. The following lists
  the names, descriptions, and values of the special request parameters that the CreateQueue
  action uses:    DelaySeconds – The length of time, in seconds, for which the delivery of
  all messages in the queue is delayed. Valid values: An integer from 0 to 900 seconds (15
  minutes). Default: 0.     MaximumMessageSize – The limit of how many bytes a message can
  contain before Amazon SQS rejects it. Valid values: An integer from 1,024 bytes (1 KiB) to
  262,144 bytes (256 KiB). Default: 262,144 (256 KiB).     MessageRetentionPeriod – The
  length of time, in seconds, for which Amazon SQS retains a message. Valid values: An
  integer from 60 seconds (1 minute) to 1,209,600 seconds (14 days). Default: 345,600 (4
  days). When you change a queue's attributes, the change can take up to 60 seconds for most
  of the attributes to propagate throughout the Amazon SQS system. Changes made to the
  MessageRetentionPeriod attribute can take up to 15 minutes and will impact existing
  messages in the queue potentially causing them to be expired and deleted if the
  MessageRetentionPeriod is reduced below the age of existing messages.    Policy – The
  queue's policy. A valid Amazon Web Services policy. For more information about policy
  structure, see Overview of Amazon Web Services IAM Policies in the IAM User Guide.
  ReceiveMessageWaitTimeSeconds – The length of time, in seconds, for which a
  ReceiveMessage  action waits for a message to arrive. Valid values: An integer from 0 to 20
  (seconds). Default: 0.     VisibilityTimeout – The visibility timeout for the queue, in
  seconds. Valid values: An integer from 0 to 43,200 (12 hours). Default: 30. For more
  information about the visibility timeout, see Visibility Timeout in the Amazon SQS
  Developer Guide.   The following attributes apply only to dead-letter queues:
  RedrivePolicy – The string that includes the parameters for the dead-letter queue
  functionality of the source queue as a JSON object. The parameters are as follows:
  deadLetterTargetArn – The Amazon Resource Name (ARN) of the dead-letter queue to which
  Amazon SQS moves messages after the value of maxReceiveCount is exceeded.
  maxReceiveCount – The number of times a message is delivered to the source queue before
  being moved to the dead-letter queue. Default: 10. When the ReceiveCount for a message
  exceeds the maxReceiveCount for a queue, Amazon SQS moves the message to the
  dead-letter-queue.      RedriveAllowPolicy – The string that includes the parameters for
  the permissions for the dead-letter queue redrive permission and which source queues can
  specify dead-letter queues as a JSON object. The parameters are as follows:
  redrivePermission – The permission type that defines which source queues can specify the
  current queue as the dead-letter queue. Valid values are:    allowAll – (Default) Any
  source queues in this Amazon Web Services account in the same Region can specify this queue
  as the dead-letter queue.    denyAll – No source queues can specify this queue as the
  dead-letter queue.    byQueue – Only queues specified by the sourceQueueArns parameter
  can specify this queue as the dead-letter queue.      sourceQueueArns – The Amazon
  Resource Names (ARN)s of the source queues that can specify this queue as the dead-letter
  queue and redrive messages. You can specify this parameter only when the redrivePermission
  parameter is set to byQueue. You can specify up to 10 source queue ARNs. To allow more than
  10 source queues to specify dead-letter queues, set the redrivePermission parameter to
  allowAll.      The dead-letter queue of a FIFO queue must also be a FIFO queue. Similarly,
  the dead-letter queue of a standard queue must also be a standard queue.  The following
  attributes apply only to server-side-encryption:    KmsMasterKeyId – The ID of an Amazon
  Web Services managed customer master key (CMK) for Amazon SQS or a custom CMK. For more
  information, see Key Terms. While the alias of the Amazon Web Services managed CMK for
  Amazon SQS is always alias/aws/sqs, the alias of a custom CMK can, for example, be
  alias/MyAlias . For more examples, see KeyId in the Key Management Service API Reference.
    KmsDataKeyReusePeriodSeconds – The length of time, in seconds, for which Amazon SQS can
  reuse a data key to encrypt or decrypt messages before calling KMS again. An integer
  representing seconds, between 60 seconds (1 minute) and 86,400 seconds (24 hours). Default:
  300 (5 minutes). A shorter time period provides better security but results in more calls
  to KMS which might incur charges after Free Tier. For more information, see How Does the
  Data Key Reuse Period Work?     SqsManagedSseEnabled – Enables server-side queue
  encryption using SQS owned encryption keys. Only one server-side encryption option is
  supported per queue (for example, SSE-KMS or SSE-SQS).   The following attributes apply
  only to FIFO (first-in-first-out) queues:    FifoQueue – Designates a queue as FIFO.
  Valid values are true and false. If you don't specify the FifoQueue attribute, Amazon SQS
  creates a standard queue. You can provide this attribute only during queue creation. You
  can't change it for an existing queue. When you set this attribute, you must also provide
  the MessageGroupId for your messages explicitly. For more information, see FIFO queue logic
  in the Amazon SQS Developer Guide.    ContentBasedDeduplication – Enables content-based
  deduplication. Valid values are true and false. For more information, see Exactly-once
  processing in the Amazon SQS Developer Guide. Note the following:    Every message must
  have a unique MessageDeduplicationId.   You may provide a MessageDeduplicationId
  explicitly.   If you aren't able to provide a MessageDeduplicationId and you enable
  ContentBasedDeduplication for your queue, Amazon SQS uses a SHA-256 hash to generate the
  MessageDeduplicationId using the body of the message (but not the attributes of the
  message).    If you don't provide a MessageDeduplicationId and the queue doesn't have
  ContentBasedDeduplication set, the action fails with an error.   If the queue has
  ContentBasedDeduplication set, your MessageDeduplicationId overrides the generated one.
  When ContentBasedDeduplication is in effect, messages with identical content sent within
  the deduplication interval are treated as duplicates and only one copy of the message is
  delivered.   If you send one message with ContentBasedDeduplication enabled and then
  another message with a MessageDeduplicationId that is the same as the one generated for the
  first MessageDeduplicationId, the two messages are treated as duplicates and only one copy
  of the message is delivered.      The following attributes apply only to high throughput
  for FIFO queues:    DeduplicationScope – Specifies whether message deduplication occurs
  at the message group or queue level. Valid values are messageGroup and queue.
  FifoThroughputLimit – Specifies whether the FIFO queue throughput quota applies to the
  entire queue or per message group. Valid values are perQueue and perMessageGroupId. The
  perMessageGroupId value is allowed only when the value for DeduplicationScope is
  messageGroup.   To enable high throughput for FIFO queues, do the following:   Set
  DeduplicationScope to messageGroup.   Set FifoThroughputLimit to perMessageGroupId.   If
  you set these attributes to anything other than the values shown for enabling high
  throughput, normal throughput is in effect and deduplication occurs as specified. For
  information on throughput quotas, see Quotas related to messages in the Amazon SQS
  Developer Guide.
- `"Tag"`: Add cost allocation tags to the specified Amazon SQS queue. For an overview, see
  Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide. When you use queue tags,
  keep the following guidelines in mind:   Adding more than 50 tags to a queue isn't
  recommended.   Tags don't have any semantic meaning. Amazon SQS interprets tags as
  character strings.   Tags are case-sensitive.   A new tag with a key identical to that of
  an existing tag overwrites the existing tag.   For a full list of tag restrictions, see
  Quotas related to queues in the Amazon SQS Developer Guide.  To be able to tag a queue on
  creation, you must have the sqs:CreateQueue and sqs:TagQueue permissions. Cross-account
  permissions don't apply to this action. For more information, see Grant cross-account
  permissions to a role and a username in the Amazon SQS Developer Guide.
"""
function create_queue(QueueName; aws_config::AbstractAWSConfig=global_aws_config())
    return sqs(
        "CreateQueue",
        Dict{String,Any}("QueueName" => QueueName);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function create_queue(
    QueueName,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "CreateQueue",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("QueueName" => QueueName), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    delete_message(queue_url, receipt_handle)
    delete_message(queue_url, receipt_handle, params::Dict{String,<:Any})

Deletes the specified message from the specified queue. To select the message to delete,
use the ReceiptHandle of the message (not the MessageId which you receive when you send the
message). Amazon SQS can delete a message from a queue even if a visibility timeout setting
causes the message to be locked by another consumer. Amazon SQS automatically deletes
messages left in a queue longer than the retention period configured for the queue.   The
ReceiptHandle is associated with a specific instance of receiving a message. If you receive
a message more than once, the ReceiptHandle is different each time you receive a message.
When you use the DeleteMessage action, you must provide the most recently received
ReceiptHandle for the message (otherwise, the request succeeds, but the message will not be
deleted). For standard queues, it is possible to receive a message even after you delete
it. This might happen on rare occasions if one of the servers which stores a copy of the
message is unavailable when you send the request to delete the message. The copy remains on
the server and might be returned to you during a subsequent receive request. You should
ensure that your application is idempotent, so that receiving a message more than once does
not cause issues.

# Arguments
- `queue_url`: The URL of the Amazon SQS queue from which messages are deleted. Queue URLs
  and names are case-sensitive.
- `receipt_handle`: The receipt handle associated with the message to delete.

"""
function delete_message(
    QueueUrl, ReceiptHandle; aws_config::AbstractAWSConfig=global_aws_config()
)
    return sqs(
        "DeleteMessage",
        Dict{String,Any}("QueueUrl" => QueueUrl, "ReceiptHandle" => ReceiptHandle);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function delete_message(
    QueueUrl,
    ReceiptHandle,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "DeleteMessage",
        Dict{String,Any}(
            mergewith(
                _merge,
                Dict{String,Any}("QueueUrl" => QueueUrl, "ReceiptHandle" => ReceiptHandle),
                params,
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    delete_message_batch(delete_message_batch_request_entry, queue_url)
    delete_message_batch(delete_message_batch_request_entry, queue_url, params::Dict{String,<:Any})

Deletes up to ten messages from the specified queue. This is a batch version of
DeleteMessage. The result of the action on each message is reported individually in the
response.  Because the batch request can result in a combination of successful and
unsuccessful actions, you should check for batch errors even when the call returns an HTTP
status code of 200.

# Arguments
- `delete_message_batch_request_entry`: Lists the receipt handles for the messages to be
  deleted.
- `queue_url`: The URL of the Amazon SQS queue from which messages are deleted. Queue URLs
  and names are case-sensitive.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Entries"`: Lists the receipt handles for the messages to be deleted.
"""
function delete_message_batch(
    DeleteMessageBatchRequestEntry,
    QueueUrl;
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "DeleteMessageBatch",
        Dict{String,Any}(
            "DeleteMessageBatchRequestEntry" => DeleteMessageBatchRequestEntry,
            "QueueUrl" => QueueUrl,
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function delete_message_batch(
    DeleteMessageBatchRequestEntry,
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "DeleteMessageBatch",
        Dict{String,Any}(
            mergewith(
                _merge,
                Dict{String,Any}(
                    "DeleteMessageBatchRequestEntry" => DeleteMessageBatchRequestEntry,
                    "QueueUrl" => QueueUrl,
                ),
                params,
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    delete_queue(queue_url)
    delete_queue(queue_url, params::Dict{String,<:Any})

Deletes the queue specified by the QueueUrl, regardless of the queue's contents.  Be
careful with the DeleteQueue action: When you delete a queue, any messages in the queue are
no longer available.   When you delete a queue, the deletion process takes up to 60
seconds. Requests you send involving that queue during the 60 seconds might succeed. For
example, a  SendMessage  request might succeed, but after 60 seconds the queue and the
message you sent no longer exist. When you delete a queue, you must wait at least 60
seconds before creating a queue with the same name.  Cross-account permissions don't apply
to this action. For more information, see Grant cross-account permissions to a role and a
username in the Amazon SQS Developer Guide. The delete operation uses the HTTP GET verb.

# Arguments
- `queue_url`: The URL of the Amazon SQS queue to delete. Queue URLs and names are
  case-sensitive.

"""
function delete_queue(QueueUrl; aws_config::AbstractAWSConfig=global_aws_config())
    return sqs(
        "DeleteQueue",
        Dict{String,Any}("QueueUrl" => QueueUrl);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function delete_queue(
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "DeleteQueue",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("QueueUrl" => QueueUrl), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    get_queue_attributes(queue_url)
    get_queue_attributes(queue_url, params::Dict{String,<:Any})

Gets attributes for the specified queue.  To determine whether a queue is FIFO, you can
check whether QueueName ends with the .fifo suffix.

# Arguments
- `queue_url`: The URL of the Amazon SQS queue whose attribute information is retrieved.
  Queue URLs and names are case-sensitive.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"AttributeNames"`: A list of attributes for which to retrieve information. The
  AttributeNames parameter is optional, but if you don't specify values for this parameter,
  the request returns empty results.  In the future, new attributes might be added. If you
  write code that calls this action, we recommend that you structure your code so that it can
  handle new attributes gracefully.  The following attributes are supported:  The
  ApproximateNumberOfMessagesDelayed, ApproximateNumberOfMessagesNotVisible, and
  ApproximateNumberOfMessages metrics may not achieve consistency until at least 1 minute
  after the producers stop sending messages. This period is required for the queue metadata
  to reach eventual consistency.      All – Returns all values.
  ApproximateNumberOfMessages – Returns the approximate number of messages available for
  retrieval from the queue.    ApproximateNumberOfMessagesDelayed – Returns the approximate
  number of messages in the queue that are delayed and not available for reading immediately.
  This can happen when the queue is configured as a delay queue or when a message has been
  sent with a delay parameter.    ApproximateNumberOfMessagesNotVisible – Returns the
  approximate number of messages that are in flight. Messages are considered to be in flight
  if they have been sent to a client but have not yet been deleted or have not yet reached
  the end of their visibility window.     CreatedTimestamp – Returns the time when the
  queue was created in seconds (epoch time).    DelaySeconds – Returns the default delay on
  the queue in seconds.    LastModifiedTimestamp – Returns the time when the queue was last
  changed in seconds (epoch time).    MaximumMessageSize – Returns the limit of how many
  bytes a message can contain before Amazon SQS rejects it.    MessageRetentionPeriod –
  Returns the length of time, in seconds, for which Amazon SQS retains a message. When you
  change a queue's attributes, the change can take up to 60 seconds for most of the
  attributes to propagate throughout the Amazon SQS system. Changes made to the
  MessageRetentionPeriod attribute can take up to 15 minutes and will impact existing
  messages in the queue potentially causing them to be expired and deleted if the
  MessageRetentionPeriod is reduced below the age of existing messages.    Policy – Returns
  the policy of the queue.    QueueArn – Returns the Amazon resource name (ARN) of the
  queue.    ReceiveMessageWaitTimeSeconds – Returns the length of time, in seconds, for
  which the ReceiveMessage action waits for a message to arrive.     VisibilityTimeout –
  Returns the visibility timeout for the queue. For more information about the visibility
  timeout, see Visibility Timeout in the Amazon SQS Developer Guide.    The following
  attributes apply only to dead-letter queues:     RedrivePolicy – The string that includes
  the parameters for the dead-letter queue functionality of the source queue as a JSON
  object. The parameters are as follows:    deadLetterTargetArn – The Amazon Resource Name
  (ARN) of the dead-letter queue to which Amazon SQS moves messages after the value of
  maxReceiveCount is exceeded.    maxReceiveCount – The number of times a message is
  delivered to the source queue before being moved to the dead-letter queue. Default: 10.
  When the ReceiveCount for a message exceeds the maxReceiveCount for a queue, Amazon SQS
  moves the message to the dead-letter-queue.      RedriveAllowPolicy – The string that
  includes the parameters for the permissions for the dead-letter queue redrive permission
  and which source queues can specify dead-letter queues as a JSON object. The parameters are
  as follows:    redrivePermission – The permission type that defines which source queues
  can specify the current queue as the dead-letter queue. Valid values are:    allowAll –
  (Default) Any source queues in this Amazon Web Services account in the same Region can
  specify this queue as the dead-letter queue.    denyAll – No source queues can specify
  this queue as the dead-letter queue.    byQueue – Only queues specified by the
  sourceQueueArns parameter can specify this queue as the dead-letter queue.
  sourceQueueArns – The Amazon Resource Names (ARN)s of the source queues that can specify
  this queue as the dead-letter queue and redrive messages. You can specify this parameter
  only when the redrivePermission parameter is set to byQueue. You can specify up to 10
  source queue ARNs. To allow more than 10 source queues to specify dead-letter queues, set
  the redrivePermission parameter to allowAll.      The dead-letter queue of a FIFO queue
  must also be a FIFO queue. Similarly, the dead-letter queue of a standard queue must also
  be a standard queue.  The following attributes apply only to server-side-encryption:
  KmsMasterKeyId – Returns the ID of an Amazon Web Services managed customer master key
  (CMK) for Amazon SQS or a custom CMK. For more information, see Key Terms.
  KmsDataKeyReusePeriodSeconds – Returns the length of time, in seconds, for which Amazon
  SQS can reuse a data key to encrypt or decrypt messages before calling KMS again. For more
  information, see How Does the Data Key Reuse Period Work?.     SqsManagedSseEnabled –
  Returns information about whether the queue is using SSE-SQS encryption using SQS owned
  encryption keys. Only one server-side encryption option is supported per queue (for
  example, SSE-KMS or SSE-SQS).   The following attributes apply only to FIFO
  (first-in-first-out) queues:    FifoQueue – Returns information about whether the queue
  is FIFO. For more information, see FIFO queue logic in the Amazon SQS Developer Guide.  To
  determine whether a queue is FIFO, you can check whether QueueName ends with the .fifo
  suffix.     ContentBasedDeduplication – Returns whether content-based deduplication is
  enabled for the queue. For more information, see Exactly-once processing in the Amazon SQS
  Developer Guide.    The following attributes apply only to high throughput for FIFO queues:
     DeduplicationScope – Specifies whether message deduplication occurs at the message
  group or queue level. Valid values are messageGroup and queue.    FifoThroughputLimit –
  Specifies whether the FIFO queue throughput quota applies to the entire queue or per
  message group. Valid values are perQueue and perMessageGroupId. The perMessageGroupId value
  is allowed only when the value for DeduplicationScope is messageGroup.   To enable high
  throughput for FIFO queues, do the following:   Set DeduplicationScope to messageGroup.
  Set FifoThroughputLimit to perMessageGroupId.   If you set these attributes to anything
  other than the values shown for enabling high throughput, normal throughput is in effect
  and deduplication occurs as specified. For information on throughput quotas, see Quotas
  related to messages in the Amazon SQS Developer Guide.
"""
function get_queue_attributes(QueueUrl; aws_config::AbstractAWSConfig=global_aws_config())
    return sqs(
        "GetQueueAttributes",
        Dict{String,Any}("QueueUrl" => QueueUrl);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function get_queue_attributes(
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "GetQueueAttributes",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("QueueUrl" => QueueUrl), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    get_queue_url(queue_name)
    get_queue_url(queue_name, params::Dict{String,<:Any})

Returns the URL of an existing Amazon SQS queue. To access a queue that belongs to another
AWS account, use the QueueOwnerAWSAccountId parameter to specify the account ID of the
queue's owner. The queue's owner must grant you permission to access the queue. For more
information about shared queue access, see  AddPermission  or see Allow Developers to Write
Messages to a Shared Queue in the Amazon SQS Developer Guide.

# Arguments
- `queue_name`: The name of the queue whose URL must be fetched. Maximum 80 characters.
  Valid values: alphanumeric characters, hyphens (-), and underscores (_). Queue URLs and
  names are case-sensitive.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"QueueOwnerAWSAccountId"`: The Amazon Web Services account ID of the account that
  created the queue.
"""
function get_queue_url(QueueName; aws_config::AbstractAWSConfig=global_aws_config())
    return sqs(
        "GetQueueUrl",
        Dict{String,Any}("QueueName" => QueueName);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function get_queue_url(
    QueueName,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "GetQueueUrl",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("QueueName" => QueueName), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    list_dead_letter_source_queues(queue_url)
    list_dead_letter_source_queues(queue_url, params::Dict{String,<:Any})

Returns a list of your queues that have the RedrivePolicy queue attribute configured with a
dead-letter queue.  The ListDeadLetterSourceQueues methods supports pagination. Set
parameter MaxResults in the request to specify the maximum number of results to be returned
in the response. If you do not set MaxResults, the response includes a maximum of 1,000
results. If you set MaxResults and there are additional results to display, the response
includes a value for NextToken. Use NextToken as a parameter in your next request to
ListDeadLetterSourceQueues to receive the next page of results.  For more information about
using dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon SQS
Developer Guide.

# Arguments
- `queue_url`: The URL of a dead-letter queue. Queue URLs and names are case-sensitive.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: Maximum number of results to include in the response. Value range is 1 to
  1000. You must set MaxResults to receive a value for NextToken in the response.
- `"NextToken"`: Pagination token to request the next set of results.
"""
function list_dead_letter_source_queues(
    QueueUrl; aws_config::AbstractAWSConfig=global_aws_config()
)
    return sqs(
        "ListDeadLetterSourceQueues",
        Dict{String,Any}("QueueUrl" => QueueUrl);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function list_dead_letter_source_queues(
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "ListDeadLetterSourceQueues",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("QueueUrl" => QueueUrl), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    list_message_move_tasks(source_arn)
    list_message_move_tasks(source_arn, params::Dict{String,<:Any})

Gets the most recent message movement tasks (up to 10) under a specific source queue.

# Arguments
- `source_arn`: The ARN of the queue whose message movement tasks are to be listed.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The maximum number of results to include in the response. The default is
  1, which provides the most recent message movement task. The upper limit is 10.
"""
function list_message_move_tasks(
    SourceArn; aws_config::AbstractAWSConfig=global_aws_config()
)
    return sqs(
        "ListMessageMoveTasks",
        Dict{String,Any}("SourceArn" => SourceArn);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function list_message_move_tasks(
    SourceArn,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "ListMessageMoveTasks",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("SourceArn" => SourceArn), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    list_queue_tags(queue_url)
    list_queue_tags(queue_url, params::Dict{String,<:Any})

List all cost allocation tags added to the specified Amazon SQS queue. For an overview, see
Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide.  Cross-account
permissions don't apply to this action. For more information, see Grant cross-account
permissions to a role and a username in the Amazon SQS Developer Guide.

# Arguments
- `queue_url`: The URL of the queue.

"""
function list_queue_tags(QueueUrl; aws_config::AbstractAWSConfig=global_aws_config())
    return sqs(
        "ListQueueTags",
        Dict{String,Any}("QueueUrl" => QueueUrl);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function list_queue_tags(
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "ListQueueTags",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("QueueUrl" => QueueUrl), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    list_queues()
    list_queues(params::Dict{String,<:Any})

Returns a list of your queues in the current region. The response includes a maximum of
1,000 results. If you specify a value for the optional QueueNamePrefix parameter, only
queues with a name that begins with the specified value are returned.  The listQueues
methods supports pagination. Set parameter MaxResults in the request to specify the maximum
number of results to be returned in the response. If you do not set MaxResults, the
response includes a maximum of 1,000 results. If you set MaxResults and there are
additional results to display, the response includes a value for NextToken. Use NextToken
as a parameter in your next request to listQueues to receive the next page of results.
Cross-account permissions don't apply to this action. For more information, see Grant
cross-account permissions to a role and a username in the Amazon SQS Developer Guide.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: Maximum number of results to include in the response. Value range is 1 to
  1000. You must set MaxResults to receive a value for NextToken in the response.
- `"NextToken"`: Pagination token to request the next set of results.
- `"QueueNamePrefix"`: A string to use for filtering the list results. Only those queues
  whose name begins with the specified string are returned. Queue URLs and names are
  case-sensitive.
"""
function list_queues(; aws_config::AbstractAWSConfig=global_aws_config())
    return sqs("ListQueues"; aws_config=aws_config, feature_set=SERVICE_FEATURE_SET)
end
function list_queues(
    params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()
)
    return sqs("ListQueues", params; aws_config=aws_config, feature_set=SERVICE_FEATURE_SET)
end

"""
    purge_queue(queue_url)
    purge_queue(queue_url, params::Dict{String,<:Any})

Deletes the messages in a queue specified by the QueueURL parameter.  When you use the
PurgeQueue action, you can't retrieve any messages deleted from a queue. The message
deletion process takes up to 60 seconds. We recommend waiting for 60 seconds regardless of
your queue's size.   Messages sent to the queue before you call PurgeQueue might be
received but are deleted within the next minute. Messages sent to the queue after you call
PurgeQueue might be deleted while the queue is being purged.

# Arguments
- `queue_url`: The URL of the queue from which the PurgeQueue action deletes messages.
  Queue URLs and names are case-sensitive.

"""
function purge_queue(QueueUrl; aws_config::AbstractAWSConfig=global_aws_config())
    return sqs(
        "PurgeQueue",
        Dict{String,Any}("QueueUrl" => QueueUrl);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function purge_queue(
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "PurgeQueue",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("QueueUrl" => QueueUrl), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    receive_message(queue_url)
    receive_message(queue_url, params::Dict{String,<:Any})

Retrieves one or more messages (up to 10), from the specified queue. Using the
WaitTimeSeconds parameter enables long-poll support. For more information, see Amazon SQS
Long Polling in the Amazon SQS Developer Guide.  Short poll is the default behavior where a
weighted random set of machines is sampled on a ReceiveMessage call. Thus, only the
messages on the sampled machines are returned. If the number of messages in the queue is
small (fewer than 1,000), you most likely get fewer messages than you requested per
ReceiveMessage call. If the number of messages in the queue is extremely small, you might
not receive any messages in a particular ReceiveMessage response. If this happens, repeat
the request.  For each message returned, the response includes the following:   The message
body.   An MD5 digest of the message body. For information about MD5, see RFC1321.   The
MessageId you received when you sent the message to the queue.   The receipt handle.   The
message attributes.   An MD5 digest of the message attributes.   The receipt handle is the
identifier you must provide when deleting the message. For more information, see Queue and
Message Identifiers in the Amazon SQS Developer Guide. You can provide the
VisibilityTimeout parameter in your request. The parameter is applied to the messages that
Amazon SQS returns in the response. If you don't include the parameter, the overall
visibility timeout for the queue is used for the returned messages. For more information,
see Visibility Timeout in the Amazon SQS Developer Guide. A message that isn't deleted or a
message whose visibility isn't extended before the visibility timeout expires counts as a
failed receive. Depending on the configuration of the queue, the message might be sent to
the dead-letter queue.  In the future, new attributes might be added. If you write code
that calls this action, we recommend that you structure your code so that it can handle new
attributes gracefully.

# Arguments
- `queue_url`: The URL of the Amazon SQS queue from which messages are received. Queue URLs
  and names are case-sensitive.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"AttributeNames"`: A list of attributes that need to be returned along with each
  message. These attributes include:    All – Returns all values.
  ApproximateFirstReceiveTimestamp – Returns the time the message was first received from
  the queue (epoch time in milliseconds).    ApproximateReceiveCount – Returns the number
  of times a message has been received across all queues but not deleted.    AWSTraceHeader
  – Returns the X-Ray trace header string.     SenderId    For a user, returns the user ID,
  for example ABCDEFGHI1JKLMNOPQ23R.   For an IAM role, returns the IAM role ID, for example
  ABCDE1F2GH3I4JK5LMNOP:i-a123b456.      SentTimestamp – Returns the time the message was
  sent to the queue (epoch time in milliseconds).    SqsManagedSseEnabled – Enables
  server-side queue encryption using SQS owned encryption keys. Only one server-side
  encryption option is supported per queue (for example, SSE-KMS or SSE-SQS).
  MessageDeduplicationId – Returns the value provided by the producer that calls the
  SendMessage  action.    MessageGroupId – Returns the value provided by the producer that
  calls the  SendMessage  action. Messages with the same MessageGroupId are returned in
  sequence.    SequenceNumber – Returns the value provided by Amazon SQS.
- `"MaxNumberOfMessages"`: The maximum number of messages to return. Amazon SQS never
  returns more messages than this value (however, fewer messages might be returned). Valid
  values: 1 to 10. Default: 1.
- `"MessageAttributeNames"`: The name of the message attribute, where N is the index.   The
  name can contain alphanumeric characters and the underscore (_), hyphen (-), and period
  (.).   The name is case-sensitive and must be unique among all attribute names for the
  message.   The name must not start with AWS-reserved prefixes such as AWS. or Amazon. (or
  any casing variants).   The name must not start or end with a period (.), and it should not
  have periods in succession (..).   The name can be up to 256 characters long.   When using
  ReceiveMessage, you can send a list of attribute names to receive, or you can return all of
  the attributes by specifying All or .* in your request. You can also use all message
  attributes starting with a prefix, for example bar.*.
- `"ReceiveRequestAttemptId"`: This parameter applies only to FIFO (first-in-first-out)
  queues. The token used for deduplication of ReceiveMessage calls. If a networking issue
  occurs after a ReceiveMessage action, and instead of a response you receive a generic
  error, it is possible to retry the same action with an identical ReceiveRequestAttemptId to
  retrieve the same set of messages, even if their visibility timeout has not yet expired.
  You can use ReceiveRequestAttemptId only for 5 minutes after a ReceiveMessage action.
  When you set FifoQueue, a caller of the ReceiveMessage action can provide a
  ReceiveRequestAttemptId explicitly.   If a caller of the ReceiveMessage action doesn't
  provide a ReceiveRequestAttemptId, Amazon SQS generates a ReceiveRequestAttemptId.   It is
  possible to retry the ReceiveMessage action with the same ReceiveRequestAttemptId if none
  of the messages have been modified (deleted or had their visibility changes).   During a
  visibility timeout, subsequent calls with the same ReceiveRequestAttemptId return the same
  messages and receipt handles. If a retry occurs within the deduplication interval, it
  resets the visibility timeout. For more information, see Visibility Timeout in the Amazon
  SQS Developer Guide.  If a caller of the ReceiveMessage action still processes messages
  when the visibility timeout expires and messages become visible, another worker consuming
  from the same queue can receive the same messages and therefore process duplicates. Also,
  if a consumer whose message processing time is longer than the visibility timeout tries to
  delete the processed messages, the action fails with an error. To mitigate this effect,
  ensure that your application observes a safe threshold before the visibility timeout
  expires and extend the visibility timeout as necessary.    While messages with a particular
  MessageGroupId are invisible, no more messages belonging to the same MessageGroupId are
  returned until the visibility timeout expires. You can still receive messages with another
  MessageGroupId as long as it is also visible.   If a caller of ReceiveMessage can't track
  the ReceiveRequestAttemptId, no retries work until the original visibility timeout expires.
  As a result, delays might occur but the messages in the queue remain in a strict order.
  The maximum length of ReceiveRequestAttemptId is 128 characters. ReceiveRequestAttemptId
  can contain alphanumeric characters (a-z, A-Z, 0-9) and punctuation
  (!\"#%&amp;'()*+,-./:;&lt;=&gt;?@[]^_`{|}~). For best practices of using
  ReceiveRequestAttemptId, see Using the ReceiveRequestAttemptId Request Parameter in the
  Amazon SQS Developer Guide.
- `"VisibilityTimeout"`: The duration (in seconds) that the received messages are hidden
  from subsequent retrieve requests after being retrieved by a ReceiveMessage request.
- `"WaitTimeSeconds"`: The duration (in seconds) for which the call waits for a message to
  arrive in the queue before returning. If a message is available, the call returns sooner
  than WaitTimeSeconds. If no messages are available and the wait time expires, the call
  returns successfully with an empty list of messages.  To avoid HTTP errors, ensure that the
  HTTP response timeout for ReceiveMessage requests is longer than the WaitTimeSeconds
  parameter. For example, with the Java SDK, you can set HTTP transport settings using the
  NettyNioAsyncHttpClient for asynchronous clients, or the  ApacheHttpClient for synchronous
  clients.
"""
function receive_message(QueueUrl; aws_config::AbstractAWSConfig=global_aws_config())
    return sqs(
        "ReceiveMessage",
        Dict{String,Any}("QueueUrl" => QueueUrl);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function receive_message(
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "ReceiveMessage",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("QueueUrl" => QueueUrl), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    remove_permission(label, queue_url)
    remove_permission(label, queue_url, params::Dict{String,<:Any})

Revokes any permissions in the queue policy that matches the specified Label parameter.
Only the owner of a queue can remove permissions from it.   Cross-account permissions don't
apply to this action. For more information, see Grant cross-account permissions to a role
and a username in the Amazon SQS Developer Guide.   To remove the ability to change queue
permissions, you must deny permission to the AddPermission, RemovePermission, and
SetQueueAttributes actions in your IAM policy.

# Arguments
- `label`: The identification of the permission to remove. This is the label added using
  the  AddPermission  action.
- `queue_url`: The URL of the Amazon SQS queue from which permissions are removed. Queue
  URLs and names are case-sensitive.

"""
function remove_permission(
    Label, QueueUrl; aws_config::AbstractAWSConfig=global_aws_config()
)
    return sqs(
        "RemovePermission",
        Dict{String,Any}("Label" => Label, "QueueUrl" => QueueUrl);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function remove_permission(
    Label,
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "RemovePermission",
        Dict{String,Any}(
            mergewith(
                _merge, Dict{String,Any}("Label" => Label, "QueueUrl" => QueueUrl), params
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    send_message(message_body, queue_url)
    send_message(message_body, queue_url, params::Dict{String,<:Any})

Delivers a message to the specified queue.  A message can include only XML, JSON, and
unformatted text. The following Unicode characters are allowed:  #x9 | #xA | #xD | #x20 to
#xD7FF | #xE000 to #xFFFD | #x10000 to #x10FFFF  Any characters not included in this list
will be rejected. For more information, see the W3C specification for characters.

# Arguments
- `message_body`: The message to send. The minimum size is one character. The maximum size
  is 256 KiB.  A message can include only XML, JSON, and unformatted text. The following
  Unicode characters are allowed:  #x9 | #xA | #xD | #x20 to #xD7FF | #xE000 to #xFFFD |
  #x10000 to #x10FFFF  Any characters not included in this list will be rejected. For more
  information, see the W3C specification for characters.
- `queue_url`: The URL of the Amazon SQS queue to which a message is sent. Queue URLs and
  names are case-sensitive.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"DelaySeconds"`:  The length of time, in seconds, for which to delay a specific message.
  Valid values: 0 to 900. Maximum: 15 minutes. Messages with a positive DelaySeconds value
  become available for processing after the delay period is finished. If you don't specify a
  value, the default value for the queue applies.   When you set FifoQueue, you can't set
  DelaySeconds per message. You can set this parameter only on a queue level.
- `"MessageAttribute"`: Each message attribute consists of a Name, Type, and Value. For
  more information, see Amazon SQS message attributes in the Amazon SQS Developer Guide.
- `"MessageDeduplicationId"`: This parameter applies only to FIFO (first-in-first-out)
  queues. The token used for deduplication of sent messages. If a message with a particular
  MessageDeduplicationId is sent successfully, any messages sent with the same
  MessageDeduplicationId are accepted successfully but aren't delivered during the 5-minute
  deduplication interval. For more information, see  Exactly-once processing in the Amazon
  SQS Developer Guide.   Every message must have a unique MessageDeduplicationId,   You may
  provide a MessageDeduplicationId explicitly.   If you aren't able to provide a
  MessageDeduplicationId and you enable ContentBasedDeduplication for your queue, Amazon SQS
  uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message
  (but not the attributes of the message).    If you don't provide a MessageDeduplicationId
  and the queue doesn't have ContentBasedDeduplication set, the action fails with an error.
  If the queue has ContentBasedDeduplication set, your MessageDeduplicationId overrides the
  generated one.     When ContentBasedDeduplication is in effect, messages with identical
  content sent within the deduplication interval are treated as duplicates and only one copy
  of the message is delivered.   If you send one message with ContentBasedDeduplication
  enabled and then another message with a MessageDeduplicationId that is the same as the one
  generated for the first MessageDeduplicationId, the two messages are treated as duplicates
  and only one copy of the message is delivered.     The MessageDeduplicationId is available
  to the consumer of the message (this can be useful for troubleshooting delivery issues). If
  a message is sent successfully but the acknowledgement is lost and the message is resent
  with the same MessageDeduplicationId after the deduplication interval, Amazon SQS can't
  detect duplicate messages. Amazon SQS continues to keep track of the message deduplication
  ID even after the message is received and deleted.  The maximum length of
  MessageDeduplicationId is 128 characters. MessageDeduplicationId can contain alphanumeric
  characters (a-z, A-Z, 0-9) and punctuation (!\"#%&amp;'()*+,-./:;&lt;=&gt;?@[]^_`{|}~). For
  best practices of using MessageDeduplicationId, see Using the MessageDeduplicationId
  Property in the Amazon SQS Developer Guide.
- `"MessageGroupId"`: This parameter applies only to FIFO (first-in-first-out) queues. The
  tag that specifies that a message belongs to a specific message group. Messages that belong
  to the same message group are processed in a FIFO manner (however, messages in different
  message groups might be processed out of order). To interleave multiple ordered streams
  within a single queue, use MessageGroupId values (for example, session data for multiple
  users). In this scenario, multiple consumers can process the queue, but the session data of
  each user is processed in a FIFO fashion.   You must associate a non-empty MessageGroupId
  with a message. If you don't provide a MessageGroupId, the action fails.    ReceiveMessage
  might return messages with multiple MessageGroupId values. For each MessageGroupId, the
  messages are sorted by time sent. The caller can't specify a MessageGroupId.   The length
  of MessageGroupId is 128 characters. Valid values: alphanumeric characters and punctuation
  (!\"#%&amp;'()*+,-./:;&lt;=&gt;?@[]^_`{|}~). For best practices of using MessageGroupId,
  see Using the MessageGroupId Property in the Amazon SQS Developer Guide.   MessageGroupId
  is required for FIFO queues. You can't use it for Standard queues.
- `"MessageSystemAttribute"`: The message system attribute to send. Each message system
  attribute consists of a Name, Type, and Value.    Currently, the only supported message
  system attribute is AWSTraceHeader. Its type must be String and its value must be a
  correctly formatted X-Ray trace header string.   The size of a message system attribute
  doesn't count towards the total size of a message.
"""
function send_message(
    MessageBody, QueueUrl; aws_config::AbstractAWSConfig=global_aws_config()
)
    return sqs(
        "SendMessage",
        Dict{String,Any}("MessageBody" => MessageBody, "QueueUrl" => QueueUrl);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function send_message(
    MessageBody,
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "SendMessage",
        Dict{String,Any}(
            mergewith(
                _merge,
                Dict{String,Any}("MessageBody" => MessageBody, "QueueUrl" => QueueUrl),
                params,
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    send_message_batch(queue_url, send_message_batch_request_entry)
    send_message_batch(queue_url, send_message_batch_request_entry, params::Dict{String,<:Any})

You can use SendMessageBatch to send up to 10 messages to the specified queue by assigning
either identical or different values to each message (or by not assigning values at all).
This is a batch version of  SendMessage. For a FIFO queue, multiple messages within a
single batch are enqueued in the order they are sent. The result of sending each message is
reported individually in the response. Because the batch request can result in a
combination of successful and unsuccessful actions, you should check for batch errors even
when the call returns an HTTP status code of 200. The maximum allowed individual message
size and the maximum total payload size (the sum of the individual lengths of all of the
batched messages) are both 256 KiB (262,144 bytes).  A message can include only XML, JSON,
and unformatted text. The following Unicode characters are allowed:  #x9 | #xA | #xD | #x20
to #xD7FF | #xE000 to #xFFFD | #x10000 to #x10FFFF  Any characters not included in this
list will be rejected. For more information, see the W3C specification for characters.  If
you don't specify the DelaySeconds parameter for an entry, Amazon SQS uses the default
value for the queue.

# Arguments
- `queue_url`: The URL of the Amazon SQS queue to which batched messages are sent. Queue
  URLs and names are case-sensitive.
- `send_message_batch_request_entry`: A list of  SendMessageBatchRequestEntry  items.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Entries"`: A list of  SendMessageBatchRequestEntry  items.
"""
function send_message_batch(
    QueueUrl,
    SendMessageBatchRequestEntry;
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "SendMessageBatch",
        Dict{String,Any}(
            "QueueUrl" => QueueUrl,
            "SendMessageBatchRequestEntry" => SendMessageBatchRequestEntry,
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function send_message_batch(
    QueueUrl,
    SendMessageBatchRequestEntry,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "SendMessageBatch",
        Dict{String,Any}(
            mergewith(
                _merge,
                Dict{String,Any}(
                    "QueueUrl" => QueueUrl,
                    "SendMessageBatchRequestEntry" => SendMessageBatchRequestEntry,
                ),
                params,
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    set_queue_attributes(attribute, queue_url)
    set_queue_attributes(attribute, queue_url, params::Dict{String,<:Any})

Sets the value of one or more queue attributes. When you change a queue's attributes, the
change can take up to 60 seconds for most of the attributes to propagate throughout the
Amazon SQS system. Changes made to the MessageRetentionPeriod attribute can take up to 15
minutes and will impact existing messages in the queue potentially causing them to be
expired and deleted if the MessageRetentionPeriod is reduced below the age of existing
messages.    In the future, new attributes might be added. If you write code that calls
this action, we recommend that you structure your code so that it can handle new attributes
gracefully.   Cross-account permissions don't apply to this action. For more information,
see Grant cross-account permissions to a role and a username in the Amazon SQS Developer
Guide.   To remove the ability to change queue permissions, you must deny permission to the
AddPermission, RemovePermission, and SetQueueAttributes actions in your IAM policy.

# Arguments
- `attribute`: A map of attributes to set. The following lists the names, descriptions, and
  values of the special request parameters that the SetQueueAttributes action uses:
  DelaySeconds – The length of time, in seconds, for which the delivery of all messages in
  the queue is delayed. Valid values: An integer from 0 to 900 (15 minutes). Default: 0.
  MaximumMessageSize – The limit of how many bytes a message can contain before Amazon SQS
  rejects it. Valid values: An integer from 1,024 bytes (1 KiB) up to 262,144 bytes (256
  KiB). Default: 262,144 (256 KiB).     MessageRetentionPeriod – The length of time, in
  seconds, for which Amazon SQS retains a message. Valid values: An integer representing
  seconds, from 60 (1 minute) to 1,209,600 (14 days). Default: 345,600 (4 days). When you
  change a queue's attributes, the change can take up to 60 seconds for most of the
  attributes to propagate throughout the Amazon SQS system. Changes made to the
  MessageRetentionPeriod attribute can take up to 15 minutes and will impact existing
  messages in the queue potentially causing them to be expired and deleted if the
  MessageRetentionPeriod is reduced below the age of existing messages.    Policy – The
  queue's policy. A valid Amazon Web Services policy. For more information about policy
  structure, see Overview of Amazon Web Services IAM Policies in the Identity and Access
  Management User Guide.     ReceiveMessageWaitTimeSeconds – The length of time, in
  seconds, for which a  ReceiveMessage  action waits for a message to arrive. Valid values:
  An integer from 0 to 20 (seconds). Default: 0.     VisibilityTimeout – The visibility
  timeout for the queue, in seconds. Valid values: An integer from 0 to 43,200 (12 hours).
  Default: 30. For more information about the visibility timeout, see Visibility Timeout in
  the Amazon SQS Developer Guide.   The following attributes apply only to dead-letter
  queues:     RedrivePolicy – The string that includes the parameters for the dead-letter
  queue functionality of the source queue as a JSON object. The parameters are as follows:
  deadLetterTargetArn – The Amazon Resource Name (ARN) of the dead-letter queue to which
  Amazon SQS moves messages after the value of maxReceiveCount is exceeded.
  maxReceiveCount – The number of times a message is delivered to the source queue before
  being moved to the dead-letter queue. Default: 10. When the ReceiveCount for a message
  exceeds the maxReceiveCount for a queue, Amazon SQS moves the message to the
  dead-letter-queue.      RedriveAllowPolicy – The string that includes the parameters for
  the permissions for the dead-letter queue redrive permission and which source queues can
  specify dead-letter queues as a JSON object. The parameters are as follows:
  redrivePermission – The permission type that defines which source queues can specify the
  current queue as the dead-letter queue. Valid values are:    allowAll – (Default) Any
  source queues in this Amazon Web Services account in the same Region can specify this queue
  as the dead-letter queue.    denyAll – No source queues can specify this queue as the
  dead-letter queue.    byQueue – Only queues specified by the sourceQueueArns parameter
  can specify this queue as the dead-letter queue.      sourceQueueArns – The Amazon
  Resource Names (ARN)s of the source queues that can specify this queue as the dead-letter
  queue and redrive messages. You can specify this parameter only when the redrivePermission
  parameter is set to byQueue. You can specify up to 10 source queue ARNs. To allow more than
  10 source queues to specify dead-letter queues, set the redrivePermission parameter to
  allowAll.      The dead-letter queue of a FIFO queue must also be a FIFO queue. Similarly,
  the dead-letter queue of a standard queue must also be a standard queue.  The following
  attributes apply only to server-side-encryption:    KmsMasterKeyId – The ID of an Amazon
  Web Services managed customer master key (CMK) for Amazon SQS or a custom CMK. For more
  information, see Key Terms. While the alias of the AWS-managed CMK for Amazon SQS is always
  alias/aws/sqs, the alias of a custom CMK can, for example, be alias/MyAlias . For more
  examples, see KeyId in the Key Management Service API Reference.
  KmsDataKeyReusePeriodSeconds – The length of time, in seconds, for which Amazon SQS can
  reuse a data key to encrypt or decrypt messages before calling KMS again. An integer
  representing seconds, between 60 seconds (1 minute) and 86,400 seconds (24 hours). Default:
  300 (5 minutes). A shorter time period provides better security but results in more calls
  to KMS which might incur charges after Free Tier. For more information, see How Does the
  Data Key Reuse Period Work?.     SqsManagedSseEnabled – Enables server-side queue
  encryption using SQS owned encryption keys. Only one server-side encryption option is
  supported per queue (for example, SSE-KMS or SSE-SQS).   The following attribute applies
  only to FIFO (first-in-first-out) queues:    ContentBasedDeduplication – Enables
  content-based deduplication. For more information, see Exactly-once processing in the
  Amazon SQS Developer Guide. Note the following:    Every message must have a unique
  MessageDeduplicationId.   You may provide a MessageDeduplicationId explicitly.   If you
  aren't able to provide a MessageDeduplicationId and you enable ContentBasedDeduplication
  for your queue, Amazon SQS uses a SHA-256 hash to generate the MessageDeduplicationId using
  the body of the message (but not the attributes of the message).    If you don't provide a
  MessageDeduplicationId and the queue doesn't have ContentBasedDeduplication set, the action
  fails with an error.   If the queue has ContentBasedDeduplication set, your
  MessageDeduplicationId overrides the generated one.     When ContentBasedDeduplication is
  in effect, messages with identical content sent within the deduplication interval are
  treated as duplicates and only one copy of the message is delivered.   If you send one
  message with ContentBasedDeduplication enabled and then another message with a
  MessageDeduplicationId that is the same as the one generated for the first
  MessageDeduplicationId, the two messages are treated as duplicates and only one copy of the
  message is delivered.      The following attributes apply only to high throughput for FIFO
  queues:    DeduplicationScope – Specifies whether message deduplication occurs at the
  message group or queue level. Valid values are messageGroup and queue.
  FifoThroughputLimit – Specifies whether the FIFO queue throughput quota applies to the
  entire queue or per message group. Valid values are perQueue and perMessageGroupId. The
  perMessageGroupId value is allowed only when the value for DeduplicationScope is
  messageGroup.   To enable high throughput for FIFO queues, do the following:   Set
  DeduplicationScope to messageGroup.   Set FifoThroughputLimit to perMessageGroupId.   If
  you set these attributes to anything other than the values shown for enabling high
  throughput, normal throughput is in effect and deduplication occurs as specified. For
  information on throughput quotas, see Quotas related to messages in the Amazon SQS
  Developer Guide.
- `queue_url`: The URL of the Amazon SQS queue whose attributes are set. Queue URLs and
  names are case-sensitive.

"""
function set_queue_attributes(
    Attribute, QueueUrl; aws_config::AbstractAWSConfig=global_aws_config()
)
    return sqs(
        "SetQueueAttributes",
        Dict{String,Any}("Attribute" => Attribute, "QueueUrl" => QueueUrl);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function set_queue_attributes(
    Attribute,
    QueueUrl,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "SetQueueAttributes",
        Dict{String,Any}(
            mergewith(
                _merge,
                Dict{String,Any}("Attribute" => Attribute, "QueueUrl" => QueueUrl),
                params,
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    start_message_move_task(source_arn)
    start_message_move_task(source_arn, params::Dict{String,<:Any})

Starts an asynchronous task to move messages from a specified source queue to a specified
destination queue.    This action is currently limited to supporting message redrive from
dead-letter queues (DLQs) only. In this context, the source queue is the dead-letter queue
(DLQ), while the destination queue can be the original source queue (from which the
messages were driven to the dead-letter-queue), or a custom destination queue.
Currently, only standard queues are supported.   Only one active message movement task is
supported per queue at any given time.

# Arguments
- `source_arn`: The ARN of the queue that contains the messages to be moved to another
  queue. Currently, only dead-letter queue (DLQ) ARNs are accepted.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"DestinationArn"`: The ARN of the queue that receives the moved messages. You can use
  this field to specify the destination queue where you would like to redrive messages. If
  this field is left blank, the messages will be redriven back to their respective original
  source queues.
- `"MaxNumberOfMessagesPerSecond"`: The number of messages to be moved per second (the
  message movement rate). You can use this field to define a fixed message movement rate. The
  maximum value for messages per second is 500. If this field is left blank, the system will
  optimize the rate based on the queue message backlog size, which may vary throughout the
  duration of the message movement task.
"""
function start_message_move_task(
    SourceArn; aws_config::AbstractAWSConfig=global_aws_config()
)
    return sqs(
        "StartMessageMoveTask",
        Dict{String,Any}("SourceArn" => SourceArn);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function start_message_move_task(
    SourceArn,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "StartMessageMoveTask",
        Dict{String,Any}(
            mergewith(_merge, Dict{String,Any}("SourceArn" => SourceArn), params)
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    tag_queue(queue_url, tags)
    tag_queue(queue_url, tags, params::Dict{String,<:Any})

Add cost allocation tags to the specified Amazon SQS queue. For an overview, see Tagging
Your Amazon SQS Queues in the Amazon SQS Developer Guide. When you use queue tags, keep the
following guidelines in mind:   Adding more than 50 tags to a queue isn't recommended.
Tags don't have any semantic meaning. Amazon SQS interprets tags as character strings.
Tags are case-sensitive.   A new tag with a key identical to that of an existing tag
overwrites the existing tag.   For a full list of tag restrictions, see Quotas related to
queues in the Amazon SQS Developer Guide.  Cross-account permissions don't apply to this
action. For more information, see Grant cross-account permissions to a role and a username
in the Amazon SQS Developer Guide.

# Arguments
- `queue_url`: The URL of the queue.
- `tags`: The list of tags to be added to the specified queue.

"""
function tag_queue(QueueUrl, Tags; aws_config::AbstractAWSConfig=global_aws_config())
    return sqs(
        "TagQueue",
        Dict{String,Any}("QueueUrl" => QueueUrl, "Tags" => Tags);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function tag_queue(
    QueueUrl,
    Tags,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "TagQueue",
        Dict{String,Any}(
            mergewith(
                _merge, Dict{String,Any}("QueueUrl" => QueueUrl, "Tags" => Tags), params
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end

"""
    untag_queue(queue_url, tag_key)
    untag_queue(queue_url, tag_key, params::Dict{String,<:Any})

Remove cost allocation tags from the specified Amazon SQS queue. For an overview, see
Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide.  Cross-account
permissions don't apply to this action. For more information, see Grant cross-account
permissions to a role and a username in the Amazon SQS Developer Guide.

# Arguments
- `queue_url`: The URL of the queue.
- `tag_key`: The list of tags to be removed from the specified queue.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"TagKeys"`: The list of tags to be removed from the specified queue.
"""
function untag_queue(QueueUrl, TagKey; aws_config::AbstractAWSConfig=global_aws_config())
    return sqs(
        "UntagQueue",
        Dict{String,Any}("QueueUrl" => QueueUrl, "TagKey" => TagKey);
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
function untag_queue(
    QueueUrl,
    TagKey,
    params::AbstractDict{String};
    aws_config::AbstractAWSConfig=global_aws_config(),
)
    return sqs(
        "UntagQueue",
        Dict{String,Any}(
            mergewith(
                _merge, Dict{String,Any}("QueueUrl" => QueueUrl, "TagKey" => TagKey), params
            ),
        );
        aws_config=aws_config,
        feature_set=SERVICE_FEATURE_SET,
    )
end
